import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
import pandas as pd
from datetime import datetime
from loguru import logger
import mns_scheduler.company_info.constant.company_constant_data as company_constant_data
import mns_common.constant.db_name_constant as db_name_constant
import mns_scheduler.concept.ths.detaill.ths_concept_detail_api as ths_concept_detail_api
import mns_scheduler.company_info.base.sync_company_base_info_api as company_info_sync_api
import mns_common.utils.data_frame_util as data_frame_util

mongodb_util = MongodbUtil('27017')
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.company.company_common_service_api as company_common_service_api


# 修改行业信息
def clean_company_info(symbol):
    if symbol is not None:
        query = {"symbol": symbol}
        company_info = mongodb_util.find_query_data('company_info_base', query)
    else:
        company_info = mongodb_util.find_all_data('company_info_base')

    company_info = company_constant_data.fix_second_industry(company_info)

    company_info = company_info.set_index(['second_sw_industry'], drop=False)

    # 修改行业名称
    del company_info['industry']
    # fix industry  name
    industry_final_fix_df = company_constant_data.get_fix_industry_name_df()
    industry_final_fix_df = industry_final_fix_df.set_index(['second_sw_industry'], drop=True)
    company_info = pd.merge(company_info, industry_final_fix_df, how='outer',
                            left_index=True, right_index=True)

    # 将申万第三行业做为行业 拆分过大的二级行业 主要有通用设备 和专业设备
    company_info = company_constant_data.fix_industry_use_sw_third(company_info.copy())
    company_info['industry'] = company_info['industry'].fillna('综合')
    company_info = company_constant_data.filed_sort(company_info)
    company_info['company_type'] = company_info['business_nature']

    # 将list_date列中的所有NaN值设置为99990909
    company_info.fillna({'list_date': 19890604}, inplace=True)

    # 将日期数值转换为日期时间格式
    company_info['list_date_01'] = pd.to_datetime(company_info['list_date'], format='%Y%m%d')

    company_info['list_date'] = company_info['list_date'].apply(
        lambda x: pd.to_numeric(x, errors="coerce"))

    now_date = datetime.now()

    # 计算日期差值 距离现在上市时间
    company_info['diff_days'] = company_info.apply(
        lambda row: (now_date - row['list_date_01']).days, axis=1)

    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    company_info['sync_date'] = str_now_date

    try:
        # 次新股
        sub_stock = ths_concept_detail_api.get_ths_concept_detail('885598', None)
        sub_stock_symbol_list = list(sub_stock['symbol'])
    except BaseException as e:
        logger.error("出现异常:{},{}", symbol, e)
        query = {'concept_code': 885598}
        ths_stock_concept_detail = mongodb_util.find_query_data(db_name_constant.THS_STOCK_CONCEPT_DETAIL, query)
        sub_stock_symbol_list = list(ths_stock_concept_detail['symbol'])
    company_info.loc[:, 'sub_stock'] = False
    company_info.loc[company_info['symbol'].isin(sub_stock_symbol_list), 'sub_stock'] = True

    try:
        company_info.dropna(subset=['symbol'], axis=0, inplace=True)
        company_info.dropna(subset=['_id'], axis=0, inplace=True)
        ths_stock_industry_detail_df = mongodb_util.find_all_data(db_name_constant.THS_STOCK_INDUSTRY_DETAIL)
        if data_frame_util.is_not_empty(ths_stock_industry_detail_df):
            ths_stock_industry_detail_df = ths_stock_industry_detail_df[
                ['symbol', 'ths_industry_name', 'ths_industry_code']]
            ths_stock_industry_detail_df = ths_stock_industry_detail_df.set_index(['symbol'], drop=True)
            company_info = company_info.set_index(['_id'], drop=False)
            company_info = pd.merge(company_info, ths_stock_industry_detail_df, how='outer',
                                    left_index=True, right_index=True)
            company_info['ths_industry_code'] = company_info['ths_industry_code'].fillna('0')
            company_info['ths_industry_name'] = company_info['ths_industry_name'].fillna('异常')

        else:
            company_info['ths_industry_code'] = '0'
            company_info['ths_industry_name'] = '异常'
        mongodb_util.save_mongo(company_info, db_name_constant.COMPANY_INFO)
        # 保存历史数据
        save_company_info_his(company_info)
    except BaseException as e:
        logger.error("出现异常:{},{}", symbol, e)

    return company_info


def save_company_info_his(company_info_df):
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    company_info_df['symbol'] = company_info_df['_id']
    company_info_df['str_day'] = str_day
    company_info_df['_id'] = company_info_df['_id'] + "_" + str_day
    remove_query = {'str_day': str_day}
    tag = mongodb_util.remove_data(remove_query, db_name_constant.COMPANY_INFO_HIS)
    success = tag.acknowledged
    if success:
        mongodb_util.save_mongo(company_info_df, db_name_constant.COMPANY_INFO_HIS)


# 更新新上市公司信息
def new_company_info_update():
    east_money_stock_info = company_info_sync_api.get_east_money_stock_info()
    new_stock = common_service_fun_api.get_new_stock(east_money_stock_info.copy())
    for company_one in new_stock.itertuples():
        try:
            company_info_sync_api.sync_company_base_info([company_one.symbol])
            clean_company_info(company_one.symbol)

        except BaseException as e:
            logger.error("出现异常:{}", e)
    company_common_service_api.company_info_industry_cache_clear


if __name__ == '__main__':
    clean_company_info(None)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.utils.cmd_util as cmd_util
import time
import mns_scheduler.trade.auto_login.trader_auto_service as trader_auto_service
import mns_common.utils.data_frame_util as data_frame_util
from loguru import logger

# 交易服务端
TRADER_SERVER_PATH = 'H:\\mns_trader_server.bat'
# 实时行情同步任务 python名称
TRADER_SERVER_NAME = "mns_trader_server"


# 打开交易客户端
def open_trader_terminal():
    # 打开 [交易web服务端]
    logger.info('打开 [交易web服务端]')
    if bool(1- is_open_trader_server()):
        cmd_util.open_bat_file(TRADER_SERVER_PATH)
    time.sleep(10)
    logger.info('自动登陆ths和qmt')
    # 自动登陆ths和qmt
    trader_auto_service.auto_login()
    time.sleep(5)
    # 杀死[交易web服务端]，使用同花顺需要先打开xiadan.exe，在重新打开[交易web服务端]
    logger.info('杀死[交易web服务端]')
    kill_server()
    time.sleep(5)
    logger.info('重新打开 [交易web服务端]')
    # 重新打开 [交易web服务端]
    cmd_util.open_bat_file(TRADER_SERVER_PATH)


def is_open_trader_server():
    all_cmd_processes = cmd_util.get_all_process()
    all_cmd_processes_trader = all_cmd_processes.loc[
        (all_cmd_processes['total_info'].str.contains(TRADER_SERVER_NAME, case=False, na=False))]
    if data_frame_util.is_not_empty(all_cmd_processes_trader):
        return True
    else:
        return False


def kill_server():
    all_cmd_processes = cmd_util.get_all_process()
    all_cmd_processes_trader = all_cmd_processes.loc[
        (all_cmd_processes['total_info'].str.contains(TRADER_SERVER_NAME, case=False, na=False))]
    if data_frame_util.is_not_empty(all_cmd_processes_trader):
        for processes_one in all_cmd_processes_trader.itertuples():
            try:
                process_pid = processes_one.process_pid
                cmd_util.kill_process_by_pid(process_pid)
            except BaseException as e:
                logger.error("杀死进程异常:{}", e)


if __name__ == '__main__':
    # kill_server()
    open_trader_terminal()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from datetime import datetime
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.api.msg.push_msg_api as push_msg_api

mongodb_util = MongodbUtil('27017')

min_k_line_count = 5200


# check下一个交易日k线同步状态
def check_k_line_sync_count():
    now_date = datetime.now()
    str_day = now_date.strftime('%Y-%m-%d')
    hour = now_date.hour
    # 是否是交易日
    if trade_date_common_service_api.is_trade_day(str_day):
        if hour > 15:
            qfq_day = str_day
            k_line_day = trade_date_common_service_api.get_further_trade_date(str_day, 2)
        else:
            qfq_day = trade_date_common_service_api.get_last_trade_day(str_day)
            k_line_day = str_day
    else:
        qfq_day = trade_date_common_service_api.get_last_trade_day(str_day)
        k_line_day = trade_date_common_service_api.get_further_trade_date(str_day, 1)

    # check 当日k线同步状态
    query_qfq = {'date': date_handle_util.no_slash_date(qfq_day)}
    qfq_k_line_count = mongodb_util.count(query_qfq, db_name_constant.STOCK_QFQ_DAILY)
    if qfq_k_line_count < min_k_line_count:
        title = '当日k线同步数量不对'
        msg = '当日k线同步数量不对,当前k线数量:' + str(qfq_k_line_count)
        push_msg_api.push_msg_to_wechat(title, msg)

    query_last_trade = {'str_day': k_line_day}
    last_trade_day_k_line_count = mongodb_util.count(query_last_trade, 'k_line_info')
    if last_trade_day_k_line_count < min_k_line_count:
        title = '下一个交易日策略k线数量不对'
        msg = '下一个交易日策略k线数量不对,当前数量:' + str(last_trade_day_k_line_count)
        push_msg_api.push_msg_to_wechat(title, msg)


if __name__ == '__main__':
    check_k_line_sync_count()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.component.tfp.stock_tfp_api as stock_tfp_api
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.common_service_fun_api as common_service_fun_api

mongodb_util = MongodbUtil('27017')


def sync_stock_tfp(str_day):
    stock_tfp_df = stock_tfp_api.get_stock_tfp_by_day(str_day)
    if data_frame_util.is_not_empty(stock_tfp_df):
        stock_tfp_df['sus_begin_time'] = stock_tfp_df['sus_begin_time'].fillna('无')
        stock_tfp_df['sus_end_time'] = stock_tfp_df['sus_end_time'].fillna('无')
        stock_tfp_df['resume_time'] = stock_tfp_df['resume_time'].fillna('无')
        stock_tfp_df['_id'] = stock_tfp_df['symbol'] + "_" + str_day
        # 排除name列中值包含'B'的行
        stock_tfp_df = stock_tfp_df[~stock_tfp_df['name'].str.contains('B', na=False)]

        stock_tfp_df['sus_begin_time'] = stock_tfp_df['sus_begin_time'].astype(str)
        stock_tfp_df['sus_end_time'] = stock_tfp_df['sus_end_time'].astype(str)
        stock_tfp_df['resume_time'] = stock_tfp_df['resume_time'].astype(str)
        stock_tfp_df['sus_begin_date'] = stock_tfp_df['sus_begin_date'].astype(str)
        stock_tfp_df = common_service_fun_api.exclude_st_symbol(stock_tfp_df)
        # 根据条件设置新列'type'的值

        # 初始化类型值
        stock_tfp_df['type'] = '0'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '盘中停牌', 'type'] = '0'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '停牌一天', 'type'] = '1'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '连续停牌', 'type'] = '2'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '刊登重要公告', 'type'] = '3'
        stock_tfp_df.loc[stock_tfp_df['sus_reason'] == '拟筹划重大资产重组', 'type'] = '4'
        stock_tfp_df['valid'] = True
        stock_tfp_df['str_day'] = str_day
        stock_tfp_df.loc[stock_tfp_df['type'] == '2', 'valid'] = False
        stock_tfp_df.loc[stock_tfp_df['type'] == '1', 'valid'] = False

        stock_tfp_df = stock_tfp_df.fillna(0)

        mongodb_util.save_mongo(stock_tfp_df, db_name_constant.STOCK_TFP_INFO)

    return stock_tfp_df


if __name__ == '__main__':
    df = sync_stock_tfp('2025-07-30')
    print(df)



import sys
import os
import mns_common.component.concept.kpl_concept_common_service_api as kpl_concept_common_service_api
import mns_common.api.kpl.selection.kpl_selection_plate_api as selection_plate_api
from mns_common.db.MongodbUtil import MongodbUtil
from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
import mns_scheduler.kpl.selection.index.sync_best_choose_index as sync_best_choose_first_index
import mns_scheduler.kpl.selection.symbol.sync_best_choose_symbol as sync_best_choose_symbol
import threading
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.api.kpl.constant.kpl_constant as kpl_constant
import mns_scheduler.kpl.selection.symbol.sync_kpl_concept_symbol_choose_reason_api as sync_kpl_concept_symbol_choose_reason_api

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)

mongodb_util = MongodbUtil('27017')

# 分页大小
MAX_PAGE_NUMBER = 10


# 同步开盘啦精选概念股票组成
def sync_best_choose_symbol_detail(first_index_df, page_number):
    for stock_one in first_index_df.itertuples():
        try:
            # 保存一级精选指数股票组成
            sync_best_choose_symbol.save_one_plate_detail_data(stock_one.plate_code,
                                                               stock_one.plate_name,
                                                               kpl_constant.FIRST_INDEX,
                                                               stock_one.plate_code,
                                                               stock_one.plate_name)

            kpl_best_choose_sub_index_detail = selection_plate_api.best_choose_sub_index(stock_one.plate_code)

            if data_frame_util.is_not_empty(kpl_best_choose_sub_index_detail):
                for sub_one in kpl_best_choose_sub_index_detail.itertuples():
                    try:
                        sync_best_choose_symbol.save_one_plate_detail_data(sub_one.plate_code,
                                                                           sub_one.plate_name,
                                                                           kpl_constant.SUB_INDEX,
                                                                           stock_one.plate_code,
                                                                           stock_one.plate_name)
                    except BaseException as e:
                        logger.error("同步开盘啦精选板块二级指数详情异常:{},{}", sub_one.plate_code, e)

        except BaseException as e:
            logger.error("同步开盘啦精选板块二级指数异常:{},{}", stock_one.plate_code, e)


def multi_thread_sync_kpl_best_choose_detail():
    first_index_df = sync_best_choose_first_index.choose_field_choose_first_index()
    count = first_index_df.shape[0]
    page_number = round(count / MAX_PAGE_NUMBER, 0) + 1
    page_number = int(page_number)
    threads = []
    # 创建多个线程来获取数据
    for page in range(page_number):  # 0到100页
        end_count = (page + 1) * MAX_PAGE_NUMBER
        begin_count = page * MAX_PAGE_NUMBER
        page_df = first_index_df.iloc[begin_count:end_count]
        thread = threading.Thread(target=sync_best_choose_symbol_detail, args=(page_df, page_number))
        threads.append(thread)
        thread.start()

    # 等待所有线程完成
    for thread in threads:
        thread.join()


# 同步所有精选指数信息
def sync_all_plate_info():
    # 同步第一和第二级别精选指数
    # 更新一级和二级之间的关联关系
    # 找出新增精选指数
    sync_best_choose_first_index.sync_best_choose_index()
    logger.info("同步开盘啦精选概念指数完成")
    # 同步精选概念股票组成
    multi_thread_sync_kpl_best_choose_detail()
    logger.info("同步开盘啦精选概念股票组成完成")
    # 更新开盘啦空名字名称
    update_null_name()
    logger.info("更新开盘啦空名字名称")

    # 更新开盘啦入选原因
    sync_kpl_concept_symbol_choose_reason_api.update_null_choose_reason()
    logger.info("更新开盘啦入选原因")


# 更新一二级关系
def update_best_choose_plate_relation():
    first_index_df = sync_best_choose_first_index.choose_field_choose_first_index()
    kpl_all_concept_df = kpl_concept_common_service_api.get_kpl_all_concept()
    for first_index_df_one in first_index_df.itertuples():
        try:
            kpl_best_choose_sub_index_detail = selection_plate_api.best_choose_sub_index(first_index_df_one.plate_code)
            # 更新指数级别

            kpl_one_concept_df_first = kpl_all_concept_df.loc[
                kpl_all_concept_df['plate_code'] == first_index_df_one.plate_code]

            if data_frame_util.is_not_empty(kpl_one_concept_df_first):
                kpl_one_concept_df_first_exist = kpl_one_concept_df_first.loc[
                    kpl_one_concept_df_first['index_class'] == kpl_constant.FIRST_INDEX]
                if data_frame_util.is_not_empty(kpl_one_concept_df_first_exist):
                    update_query = {"plate_code": first_index_df_one.plate_code}
                    new_values = {"$set": {"first_plate_code": first_index_df_one.plate_code,
                                           "heat_score": first_index_df_one.heat_score,
                                           "plate_name": first_index_df_one.plate_name,
                                           "first_plate_name": first_index_df_one.plate_name}}
                    mongodb_util.update_many(update_query, new_values, db_name_constant.KPL_BEST_CHOOSE_INDEX)
                else:
                    update_query = {"plate_code": first_index_df_one.plate_code}
                    new_values = {"$set": {
                        "first_plate_code": first_index_df_one.plate_code,
                        "first_plate_name": first_index_df_one.plate_name,
                        "plate_name": first_index_df_one.plate_name,
                        "index_class": kpl_constant.SUB_INDEX}}
                    mongodb_util.update_many(update_query, new_values, db_name_constant.KPL_BEST_CHOOSE_INDEX)

            if data_frame_util.is_not_empty(kpl_best_choose_sub_index_detail):
                update_query = {"plate_code": {"$in": list(kpl_best_choose_sub_index_detail['plate_code'])}}
                new_values = {"$set": {"first_plate_code": first_index_df_one.plate_code,
                                       "first_plate_name": first_index_df_one.plate_name}}
                mongodb_util.update_many(update_query, new_values, db_name_constant.KPL_BEST_CHOOSE_INDEX)
        except BaseException as e:
            logger.error("同步开盘啦精选板块指数关系异常:{},{}", first_index_df_one.plate_code, e)
    # 更新二级指数关系
    update_sub_index_relation(first_index_df, kpl_all_concept_df)


def update_sub_index_relation(first_index_df, kpl_all_concept_df):
    kpl_sub_concept_df_exist = kpl_all_concept_df.loc[
        kpl_all_concept_df['index_class'] == kpl_constant.SUB_INDEX]
    kpl_sub_concept_df_change = first_index_df.loc[
        first_index_df['plate_code'].isin(list(kpl_sub_concept_df_exist['plate_code']))]
    if data_frame_util.is_not_empty(kpl_sub_concept_df_change):
        update_query = {"plate_code": {"$in": list(kpl_sub_concept_df_change['plate_code'])}}
        new_values = {"$set": {"index_class": kpl_constant.FIRST_INDEX}}
        mongodb_util.update_many(update_query, new_values, db_name_constant.KPL_BEST_CHOOSE_INDEX)


def update_null_name():
    query = {"plate_name": ''}
    kpl_best_choose_index_df = mongodb_util.find_query_data(db_name_constant.KPL_BEST_CHOOSE_INDEX, query)
    if data_frame_util.is_empty(kpl_best_choose_index_df):
        return
    else:
        kpl_best_choose_index_df_sub = kpl_best_choose_index_df.loc[
            kpl_best_choose_index_df["index_class"] == kpl_constant.SUB_INDEX]
        if data_frame_util.is_not_empty(kpl_best_choose_index_df_sub):
            for sub_one in kpl_best_choose_index_df_sub.itertuples():
                try:
                    first_plate_code = sub_one.first_plate_code
                    sub_plate_code = sub_one.plate_code
                    kpl_best_choose_sub_index_detail = selection_plate_api.best_choose_sub_index(first_plate_code)
                    sub_kpl_best_choose_sub_index_detail = kpl_best_choose_sub_index_detail.loc[
                        kpl_best_choose_sub_index_detail['plate_code'] == sub_plate_code]
                    if data_frame_util.is_not_empty(sub_kpl_best_choose_sub_index_detail):
                        plate_name = list(sub_kpl_best_choose_sub_index_detail['plate_name'])[0]
                        new_values = {"$set": {"plate_name": plate_name}}
                        update_query = {"plate_code": sub_plate_code}
                        mongodb_util.update_many(update_query, new_values, db_name_constant.KPL_BEST_CHOOSE_INDEX)
                except BaseException as e:
                    logger.error("更新板块kpl概念名称出现异常:{},{}", sub_plate_code, e)
        kpl_best_choose_index_df_first = kpl_best_choose_index_df.loc[
            kpl_best_choose_index_df["index_class"] == kpl_constant.FIRST_INDEX]
        if data_frame_util.is_not_empty(kpl_best_choose_index_df_first):
            for first_one in kpl_best_choose_index_df_sub.itertuples():
                try:
                    first_plate_code = first_one.plate_code
                    first_index_df = sync_best_choose_first_index.choose_field_choose_first_index()
                    first_index_df_one = first_index_df.loc[first_index_df['plate_code'] == first_plate_code]
                    if data_frame_util.is_not_empty(first_index_df_one):
                        plate_name = list(first_index_df_one['plate_name'])[0]
                        new_values = {"$set": {"plate_name": plate_name}}
                        update_query = {"plate_code": first_plate_code}
                        mongodb_util.update_many(update_query, new_values, db_name_constant.KPL_BEST_CHOOSE_INDEX)
                except BaseException as e:
                    logger.error("更新板块kpl概念名称出现异常:{},{}", first_plate_code, e)

    return kpl_best_choose_index_df


if __name__ == '__main__':
    # update_null_name()
    # update_best_choose_plate_relation()

    # 同步第一和第二级别精选指数
    sync_all_plate_info()
